pub enum HttpMatchQuality {
Matched(f32),
NotMatched,
Disabled,
}Expand description
Quality classification for an HTTP match.
Matched(score)a signature was matched with the given quality score (higher is better, typically in[0.0, 1.0]).NotMatchedthe matcher was active but no signature was a viable fit.Disabledmatching was disabled (no matcher plugged in).
Variants